跳到主要内容

Owned

搜索

结构体 Owned 

源代码
pub struct Owned<'a> { /* 私有字段 */ }

实现

源代码

impl<'a> Owned<'a>

源代码

pub unsafe fn own(ptr: *mut AVDictionary) -> Self

源代码

pub unsafe fn disown(self) -> *mut AVDictionary

源代码

impl<'a> Owned<'a>

源代码

pub fn new() -> Self

Methods from Deref<Target = Ref<'a>>

源代码

pub unsafe fn as_mut_ptr(&self) -> *mut AVDictionary

源代码

pub fn set(&mut self, key: &str, value: &str)

Methods from Deref<Target = Ref<'a>>

源代码

pub unsafe fn as_ptr(&self) -> *const AVDictionary

源代码

pub fn get(&'a self, key: &str) -> Option<&'a str>

源代码

pub fn iter(&self) -> Iter<'_>

源代码

pub fn to_owned<'b>(&self) -> Owned<'b>

trait 实现

源代码

impl<'a> Clone for Owned<'a>

源代码

fn clone(&self) -> Self

Returns a duplicate of the value. 阅读更多
源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl<'a> Debug for Owned<'a>

源代码

fn fmt(&self, fmt: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl<'a> Default for Owned<'a>

源代码

fn default() -> Self

返回类型的"默认值"。 阅读更多
源代码

impl<'a> Deref for Owned<'a>

源代码

type Target = Ref<'a>

解引用之后得到的类型。
源代码

fn deref(&self) -> &Self::Target

解引用该值。
源代码

impl<'a> DerefMut for Owned<'a>

源代码

fn deref_mut(&mut self) -> &mut Self::Target

Mutably dereferences the value.
源代码

impl<'a> Drop for Owned<'a>

源代码

fn drop(&mut self)

执行该类型的析构函数。 阅读更多
源代码

impl<'a, 'b> FromIterator<&'b (&'b str, &'b str)> for Owned<'a>

源代码

fn from_iter<T: IntoIterator<Item = &'b (&'b str, &'b str)>>( iterator: T, ) -> Self

Creates a value from an iterator. 阅读更多
源代码

impl<'a, 'b> FromIterator<&'b (String, String)> for Owned<'a>

源代码

fn from_iter<T: IntoIterator<Item = &'b (String, String)>>(iterator: T) -> Self

Creates a value from an iterator. 阅读更多
源代码

impl<'a, 'b> FromIterator<(&'b str, &'b str)> for Owned<'a>

源代码

fn from_iter<T: IntoIterator<Item = (&'b str, &'b str)>>(iterator: T) -> Self

Creates a value from an iterator. 阅读更多
源代码

impl<'a> FromIterator<(String, String)> for Owned<'a>

源代码

fn from_iter<T: IntoIterator<Item = (String, String)>>(iterator: T) -> Self

Creates a value from an iterator. 阅读更多

自动 trait 实现



impl<'a> Freeze for Owned<'a>



impl<'a> RefUnwindSafe for Owned<'a>



impl<'a> !Send for Owned<'a>



impl<'a> !Sync for Owned<'a>



impl<'a> Unpin for Owned<'a>



impl<'a> UnsafeUnpin for Owned<'a>



impl<'a> UnwindSafe for Owned<'a>

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<P, T> Receiver for P
where P: Deref<Target = T> + ?Sized, T: ?Sized,

源代码

type Target = T

🔬This is a nightly-only experimental API. (arbitrary_self_types)
The target type on which the method may be called.
源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。